aboutsummaryrefslogtreecommitdiff
path: root/apps/wm.c
diff options
context:
space:
mode:
Diffstat (limited to 'apps/wm.c')
-rw-r--r--apps/wm.c148
1 files changed, 74 insertions, 74 deletions
diff --git a/apps/wm.c b/apps/wm.c
index e016eda..2443d87 100644
--- a/apps/wm.c
+++ b/apps/wm.c
@@ -3,7 +3,7 @@
#include <assert.h>
#include <cpu.h>
#include <def.h>
-#include <gui.h>
+#include <gfx.h>
#include <input.h>
#include <keymap.h>
#include <list.h>
@@ -14,52 +14,52 @@
#include <vesa.h>
static int MOUSE_SKIP = 0; // => Every move % n != 0 gets skipped
-static int window_count;
+static int context_count;
static struct vbe vbe;
-static struct window direct; // Direct video memory window
-static struct window root; // Root window (wallpaper etc.)
-static struct window exchange; // Exchange buffer
-static struct window cursor; // Cursor bitmap window
-static struct window *focused; // The focused window
-static struct list *windows; // List of all windows
+static struct context direct; // Direct video memory context
+static struct context root; // Root context (wallpaper etc.)
+static struct context exchange; // Exchange buffer
+static struct context cursor; // Cursor bitmap context
+static struct context *focused; // The focused context
+static struct list *contexts; // List of all contexts
static struct keymap *keymap;
static int mouse_x = 0;
static int mouse_y = 0;
-static struct window *new_window(struct window *win, u32 pid, int x, int y, u16 width, u16 height,
- int flags)
+static struct context *new_context(struct context *ctx, u32 pid, int x, int y, u16 width,
+ u16 height, int flags)
{
- win->pid = pid;
- win->x = x;
- win->y = y;
- win->width = width;
- win->height = height;
- win->bpp = vbe.bpp;
- win->pitch = win->width * (win->bpp >> 3);
- win->fb = malloc(height * win->pitch);
- memset(win->fb, 0, height * win->pitch);
- win->flags = flags;
- window_count++;
- if (window_count % 2 == 1)
+ ctx->pid = pid;
+ ctx->x = x;
+ ctx->y = y;
+ ctx->width = width;
+ ctx->height = height;
+ ctx->bpp = vbe.bpp;
+ ctx->pitch = ctx->width * (ctx->bpp >> 3);
+ ctx->fb = malloc(height * ctx->pitch);
+ memset(ctx->fb, 0, height * ctx->pitch);
+ ctx->flags = flags;
+ context_count++;
+ if (context_count % 2 == 1)
MOUSE_SKIP++;
- return win;
+ return ctx;
}
-static struct window *window_at(int x, int y)
+static struct context *context_at(int x, int y)
{
- if (!windows->head || !windows->head->data)
+ if (!contexts->head || !contexts->head->data)
return NULL;
- struct window *ret = NULL;
- struct node *iterator = windows->head;
+ struct context *ret = NULL;
+ struct node *iterator = contexts->head;
while (iterator != NULL) {
- struct window *win = iterator->data;
- if (win != &root && x >= win->x && x <= win->x + (int)win->width && y >= win->y &&
- y <= win->y + (int)win->height)
- ret = win;
+ struct context *ctx = iterator->data;
+ if (ctx != &root && x >= ctx->x && x <= ctx->x + (int)ctx->width && y >= ctx->y &&
+ y <= ctx->y + (int)ctx->height)
+ ret = ctx;
iterator = iterator->next;
}
return ret;
@@ -67,24 +67,24 @@ static struct window *window_at(int x, int y)
static void redraw_all()
{
- if (!windows->head || !windows->head->data)
+ if (!contexts->head || !contexts->head->data)
return;
- struct node *iterator = windows->head;
+ struct node *iterator = contexts->head;
while (iterator != NULL) {
- struct window *win = iterator->data;
- if (win != focused)
- gui_win_on_win(&exchange, win, win->x, win->y);
+ struct context *ctx = iterator->data;
+ if (ctx != focused)
+ gfx_ctx_on_ctx(&exchange, ctx, ctx->x, ctx->y);
iterator = iterator->next;
}
if (focused)
- gui_win_on_win(&exchange, focused, focused->x, focused->y);
+ gfx_ctx_on_ctx(&exchange, focused, focused->x, focused->y);
memcpy(direct.fb, exchange.fb, exchange.pitch * exchange.height);
}
// TODO: Send relative mouse position event to focused window
static int mouse_skip = 0;
static int mouse_pressed[3] = { 0 };
static void handle_mouse(struct event_mouse *event)
@@ -107,13 +107,13 @@ static void handle_mouse(struct event_mouse *event)
mouse_y = vbe.height - cursor.height - 1;
// Restore cursor buffer backup
- gui_copy(&direct, &exchange, cursor.x, cursor.y, cursor.width, cursor.height);
+ gfx_copy(&direct, &exchange, cursor.x, cursor.y, cursor.width, cursor.height);
- // Window focus
+ // Context focus
if (!mouse_pressed[0] && !mouse_pressed[1])
- focused = window_at(mouse_x, mouse_y);
+ focused = context_at(mouse_x, mouse_y);
- // Window position
+ // Context position
if (event->but1 && !mouse_pressed[1]) {
mouse_pressed[0] = 1;
if (focused && !(focused->flags & WF_NO_DRAG)) {
@@ -121,7 +121,7 @@ static void handle_mouse(struct event_mouse *event)
focused->y = mouse_y;
if (mouse_skip % MOUSE_SKIP == 0) {
mouse_skip = 0;
- redraw_all(); // TODO: Function to redraw one window
+ redraw_all(); // TODO: Function to redraw one context
}
}
} else if (mouse_pressed[0]) {
@@ -129,7 +129,7 @@ static void handle_mouse(struct event_mouse *event)
redraw_all();
}
- // Window size
+ // Context size
if (event->but2 && !mouse_pressed[0]) {
if (focused && !mouse_pressed[1]) {
mouse_x = focused->x + focused->width;
@@ -141,7 +141,7 @@ static void handle_mouse(struct event_mouse *event)
focused->width = mouse_x - focused->x;
if (mouse_y - focused->y > 0)
focused->height = mouse_y - focused->y;
- redraw_all(); // TODO: Function to redraw one window
+ redraw_all(); // TODO: Function to redraw one context
}
mouse_pressed[1] = 1;
} else if (mouse_pressed[1]) {
@@ -151,7 +151,7 @@ static void handle_mouse(struct event_mouse *event)
cursor.x = mouse_x;
cursor.y = mouse_y;
- gui_win_on_win(&direct, &cursor, cursor.x, cursor.y);
+ gfx_ctx_on_ctx(&direct, &cursor, cursor.x, cursor.y);
mouse_skip++;
}
@@ -191,26 +191,26 @@ int main(int argc, char **argv)
printf("VBE: %dx%d\n", vbe.width, vbe.height);
keymap = keymap_parse("/res/keymaps/en.keymap");
- gui_init("/font/spleen-16x32.psfu");
-
- windows = list_new();
- new_window(&root, pid, 0, 0, vbe.width, vbe.height,
- WF_NO_FOCUS | WF_NO_DRAG | WF_NO_RESIZE);
- new_window(&exchange, pid, 0, 0, vbe.width, vbe.height,
- WF_NO_FOCUS | WF_NO_DRAG | WF_NO_RESIZE);
- new_window(&cursor, pid, 0, 0, 32, 32, WF_NO_FOCUS | WF_NO_RESIZE);
+ gfx_init("/font/spleen-16x32.psfu");
+
+ contexts = list_new();
+ new_context(&root, pid, 0, 0, vbe.width, vbe.height,
+ WF_NO_FOCUS | WF_NO_DRAG | WF_NO_RESIZE);
+ new_context(&exchange, pid, 0, 0, vbe.width, vbe.height,
+ WF_NO_FOCUS | WF_NO_DRAG | WF_NO_RESIZE);
+ new_context(&cursor, pid, 0, 0, 32, 32, WF_NO_FOCUS | WF_NO_RESIZE);
memcpy(&direct, &root, sizeof(direct));
direct.fb = vbe.fb;
- list_add(windows, &root);
+ list_add(contexts, &root);
- gui_fill(&direct, COLOR_BG);
- gui_write(&direct, 0, 0, COLOR_FG, "Welcome to Melvix!");
- gui_write(&direct, 0, 32, COLOR_FG, "Loading resources...");
+ gfx_fill(&direct, COLOR_BG);
+ gfx_write(&direct, 0, 0, COLOR_FG, "Welcome to Melvix!");
+ gfx_write(&direct, 0, 32, COLOR_FG, "Loading resources...");
- gui_fill(&root, COLOR_BG);
- gui_border(&root, COLOR_FG, 2);
- gui_load_image(&cursor, "/res/cursor.bmp", 0, 0);
- gui_load_wallpaper(&root, "/res/wall.bmp");
+ gfx_fill(&root, COLOR_BG);
+ gfx_border(&root, COLOR_FG, 2);
+ gfx_load_image(&cursor, "/res/cursor.bmp", 0, 0);
+ gfx_load_wallpaper(&root, "/res/wall.bmp");
redraw_all();
event_register(EVENT_MOUSE);
@@ -224,19 +224,19 @@ int main(int argc, char **argv)
}
switch (msg->type) {
- case WM_NEW_WINDOW:
- printf("New window for pid %d\n", msg->src);
- struct window *win = msg->data;
- int width = win->width ? win->width : 1000;
- int height = win->height ? win->height : 800;
- int x = win->x ? win->x : vbe.width / 2 - (width / 2);
- int y = win->y ? win->y : vbe.height / 2 - (height / 2);
- win->pid = msg->src;
- new_window(win, msg->src, x, y, width, height, win->flags);
- msg_send(msg->src, WM_NEW_WINDOW, win);
- list_add(windows, win);
- focused = win;
+ case WM_NEW_CONTEXT:
+ printf("New context for pid %d\n", msg->src);
+ struct context *ctx = msg->data;
+ int width = ctx->width ? ctx->width : 1000;
+ int height = ctx->height ? ctx->height : 800;
+ int x = ctx->x ? ctx->x : vbe.width / 2 - (width / 2);
+ int y = ctx->y ? ctx->y : vbe.height / 2 - (height / 2);
+ ctx->pid = msg->src;
+ new_context(ctx, msg->src, x, y, width, height, ctx->flags);
+ list_add(contexts, ctx);
+ focused = ctx;
redraw_all();
+ msg_send(msg->src, WM_NEW_CONTEXT, ctx);
break;
case WM_REDRAW:
redraw_all();
@@ -67,24 +67,24 @@ static struct window *window_at(int x, int y)
memcpy(direct.fb, exchange.fb, exchange.pitch * exchange.height);
}
-// TODO: Send relative mouse position event to focused window
+// TODO: Send relative mouse position event to focused context
static int mouse_skip = 0;
static int mouse_pressed[3] = { 0 };